.. module:: cratermaker

Cratermaker
====================
Simulate the evolution of a landscape dominated by impact bombardment.

**Useful links**:
`Home <https://cratermaker.readthedocs.io/en/latest/>`__ |
`Code Repository <https://github.com/MintonGroup/cratermaker>`__ |
`Issues <https://github.com/MintonGroup/cratermaker/issues>`__ |
`Discussions <https://github.com/MintonGroup/cratermaker/discussions>`__ |
`Releases <https://github.com/MintonGroup/cratermaker/releases>`__ |
`Contributing Guide <contributing>`__ 


.. grid:: 1 1 2 2
    :gutter: 2


    .. grid-item-card::  User guide
        :img-top: _static/crater_icon.svg
        :link: user-guide/index
        :link-type: doc

        The user guide will show you how to install and run Cratermaker. It also contains in-depth information on how to use each of its components.  

    .. grid-item-card::  Example gallery
        :img-top: _static/index_gallery.svg
        :link: auto_examples/index
        :link-type: doc

        See full working examples of how to use Cratermaker.

    .. grid-item-card::  API reference
        :img-top: _static/index_api_reference.svg
        :link: api/index
        :link-type: doc

        The API guide contains a detailed description of the Cratermaker API.
        The reference describes how the methods work and which parameters can
        be used. It assumes that you have an understanding of the key concepts.

    .. grid-item-card:: Contributor's guide
        :img-top: _static/index_contributing.svg
        :link: contributing/index
        :link-type: doc

        The contributor's guide contains information on how to contribute to Cratermaker. It also contains information on how to set up a development environment and how to run the tests.



.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: For users

   User Guide <user-guide/index>
   Gallery <auto_examples/index>
   API Reference <api/index>
   Publications <publications>

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: For developers/contributors

   Contributing Guide <contributing/index>
   What's New <whats-new>
   GitHub repository <https://github.com/MintonGroup/cratermaker>
   GitHub discussions <https://github.com/MintonGroup/cratermaker/discussions>
   License <license>